==> xsnow_3.0.7.orig.tar.gz: xsnow-3.0.7/src/loadmeasure.c <==
/* -copyright-
#-# 
#-# xsnow: let it snow on your desktop
#-# Copyright (C) 1984,1988,1990,1993-1995,2000-2001 Rick Jansen
#-#               2019,2020 Willem Vermin
#-# 
#-# This program is free software: you can redistribute it and/or modify
#-# it under the terms of the GNU General Public License as published by
#-# the Free Software Foundation, either version 3 of the License, or
#-# (at your option) any later version.
#-# 
#-# This program is distributed in the hope that it will be useful,
#-# but WITHOUT ANY WARRANTY; without even the implied warranty of
#-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#-# GNU General Public License for more details.
#-# 
#-# You should have received a copy of the GNU General Public License
#-# along with this program.  If not, see <http://www.gnu.org/licenses/>.
#-# 
 */

#include <stdio.h>
#include <gtk/gtk.h>
#include <stdlib.h>
#include "debug.h"
#include "loadmeasure.h"
#include "ui.h"
#include "utils.h"
#include "clocks.h"
#include "xsnow.h"

static int do_loadmeasure(gpointer data);

int loadmeasure_ui()
{
   // nothing to do
   return 0;
}
void loadmeasure_draw(cairo_t *cr)
{
   // nothing to draw
   //
}

void loadmeasure_init()
{
   add_to_mainloop(PRIORITY_DEFAULT, time_measure, do_loadmeasure, 0);
}

// changes background color of ui if load to high
int do_loadmeasure(gpointer data)
{
   double tnow = wallclock();
   static double tprev;
   static int count = 0;
   static int status   = 0;

   if (tnow-tprev > 1.1*time_measure)
      count++;
   else 
      count --;
   P(" %d %d %f %f\n",count,status,time_measure,tnow-tprev);

   if (count > 10)
   {
      if (status == 0)
      {
	 P("pink %d %d %f %f\n",count,status,time_measure,tnow-tprev);
	 printf("system is too busy, suggest to lower 'cpu load' in 'settings'\n");
	 printf(" or have a look at 'snow': 'Intensity', 'Max # of flakes', ...\n");
	 printf(" or specify a smaller number of birds in 'birds'\n");
	 ui_background(1);
	 status = 1;
      }
      count = 0;
   }
   if (count < -10)
   {
      if (status == 1)
      {
	 P("white %d %d %f %f\n",count,status,time_measure,tnow-tprev);
	 ui_background(0);
	 status = 0;
      }
      count = 0;
   }
   tprev = tnow;
   return TRUE;
}

==> xsnow_3.1.1.orig.tar.gz: xsnow-3.1.1/src/loadmeasure.c <==
/* -copyright-
#-# 
#-# xsnow: let it snow on your desktop
#-# Copyright (C) 1984,1988,1990,1993-1995,2000-2001 Rick Jansen
#-# 	      2019,2020 Willem Vermin
#-# 
#-# This program is free software: you can redistribute it and/or modify
#-# it under the terms of the GNU General Public License as published by
#-# the Free Software Foundation, either version 3 of the License, or
#-# (at your option) any later version.
#-# 
#-# This program is distributed in the hope that it will be useful,
#-# but WITHOUT ANY WARRANTY; without even the implied warranty of
#-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#-# GNU General Public License for more details.
#-# 
#-# You should have received a copy of the GNU General Public License
#-# along with this program.  If not, see <http://www.gnu.org/licenses/>.
#-# 
 */

#include <stdio.h>
#include <gtk/gtk.h>
#include <stdlib.h>
#include "debug.h"
#include "loadmeasure.h"
#include "ui.h"
#include "utils.h"
#include "clocks.h"
#include "xsnow.h"
#include "varia.h"

static int do_loadmeasure(gpointer data);

int loadmeasure_ui()
{
   // nothing to do
   return 0;
}
void loadmeasure_draw(UNUSED cairo_t *cr)
{
   // nothing to draw
   //
}

void loadmeasure_init()
{
   add_to_mainloop(PRIORITY_DEFAULT, time_measure, do_loadmeasure, NULL);
}

// changes background color of ui if load to high
int do_loadmeasure(UNUSED gpointer data)
{
   double tnow = wallclock();
   static double tprev;
   static int count = 0;
   static int status   = 0;

   if (tnow-tprev > 1.1*time_measure)
      count++;
   else 
      count --;
   P(" %d %d %f %f\n",count,status,time_measure,tnow-tprev);

   if (count > 10)
   {
      if (status == 0)
      {
	 P("pink %d %d %f %f\n",count,status,time_measure,tnow-tprev);
	 printf("system is too busy, suggest to lower 'cpu load' in 'settings'\n");
	 printf(" or have a look at 'snow': 'Intensity', 'Max # of flakes', ...\n");
	 printf(" or specify a smaller number of birds in 'birds'\n");
	 ui_background(1);
	 status = 1;
      }
      count = 0;
   }
   if (count < -10)
   {
      if (status == 1)
      {
	 P("white %d %d %f %f\n",count,status,time_measure,tnow-tprev);
	 ui_background(0);
	 status = 0;
      }
      count = 0;
   }
   tprev = tnow;
   return TRUE;
}
